function bridgemass
%Calculates the weight of the bridge per unit length and compares to the
%values from the NPRA

rho_s = 7.850;  %density of steel, ton/m^3
g = 9.81;       %acceleration of gravity, m/s^2

%Main girder cross-section areas
%Added area due to weight of asphalt, railings, etc
A_s1 = 2.50+11*0.01*2; 
A_f1 = 1.85+11*0.01*2;
A_h1 = 1.85;

%Main girder weight per unit length
we_s1 = A_s1*rho_s;
we_f1 = A_f1*rho_s;
we_h1 = A_h1*rho_s;

%Crossbeam cross-section area
A_cross = 0.708;

%Crossbeam weight per unit length of low-bridge and high-bridge
l = 38;
b_sf = 197/4;
b_h = 40; 
we_cr_sf = (A_cross*l/b_sf)*rho_s;
we_cr_h = (A_cross*l/b_h)*rho_s;

%Pedestrian cross-section area
b_p = 2;
h_p = 5;
t_p = 0.055;
A_p = b_p*t_p*2 + (h_p-2*t_p)*t_p*2;

%Pedestrian beam weight per unit length
we_p = A_p*rho_s;

%Total weight from NPRA [ton/m]
we_act_s1 = 312/g;
we_act_f1 = 262/g;
we_act_h1 = (235*330+284*125+325*25+312*10)/(490*g);

%Total calculated weight [ton/m]
we_tot_s1 = we_s1+we_cr_sf+we_p;
we_tot_f1 = we_f1+we_cr_sf+we_p;
we_tot_h1 = we_h1+we_cr_h+we_p; 

fprintf('    Calculated / From NPRA \n S1: %f / %f \n F1: %f / %f \n H1: %f / %f\n', we_tot_s1,...
    we_act_s1, we_tot_f1, we_act_f1, we_tot_h1, we_act_h1)

end