function [S_om, Tp, Hs, om, dom, n, A_n] = jonswap()

Tp = [5.3,5.9,6.6]; 
gam = 3.3;
A_gam = (1-0.287*log(gam));
Hs = [1.6,2.2,2.8];

dom = 0.005;        %frequency step
om = 0.48:dom:6;    %relevant frequency range
T = (2*pi)./om;
n = length(om);
S_om = zeros(n,3);

A_n = zeros(n,3);

%legendinfo = zeros(3,1);
figure 
for state = 1:3
    om_p = (2*pi)/Tp(state);

for i = 1:n
    
%===============Spectrum calculations===============%    
    if om(i) <= om_p
        sig = 0.07;
    else
        sig = 0.09;
    end
r = exp(-0.5*((om(i)-om_p)/(sig*om_p))^2);
S_om(i,state) = A_gam*(5/16)*Hs(state)^2*om_p^4*(om(i))^(-5)*...
    exp(-(5/4)*(om(i)/om_p)^-4)*gam^r;

%===============Surface elevation===============%

A_n(i,state) = sqrt(2*S_om(i, state)*dom);

S_T(i,state) = S_om(i,state)*2*pi;

end


plot(om,S_om(:,state),'linewidth',2), hold on
set(gca,'FontSize',14)
legendinfo{state} = ['Tp = ', num2str(Tp(state)),', Hs = ', num2str(Hs(state))];
title('JONSWAP spectra with respect to wave frequency')
legend(legendinfo)
xlabel('\omega')
ylabel('S(\omega)')
axis([0 5 0 1.8])

% plot(T,S_T(:,state), 'linewidth',2), hold on
% set(gca,'FontSize',14)
% legendinfo{state} = ['Tp = ', num2str(Tp(state)),', Hs = ', num2str(Hs(state))];
% title('JONSWAP spectra with respect to period')
% legend(legendinfo)
% xlabel('Period, T [s]')
% ylabel('S(T) [m^2/Hz]')
% axis([0 12 0 12])

end
end
