function regularforce()

%Pontoon dimensions. Treat like a rectangular box
B = 28;
L = 68;
%r = b/2;
d = 10.5;
f = 5; %width of flange

z = -d;
zm= z/2;
g = 9.81;
rho = 1025;

A_n = 1;    %unit amplitude

[~,~,~,om,~,~,~] = jonswap;
[Ma_heave, ~, Ma_sway] = addedmass;

dt = 0.2;           %time step length
tmax = 300;         %total time
t = 0:dt:tmax;      %time vector
nt = length(t);     %number of time steps

F_fkh = zeros(nt,13);
F_dh = zeros(nt,13);

F_fks = zeros(nt,13);
F_ds = zeros(nt,13);

F_fkr = zeros(nt,13);
F_dr = zeros(nt,13);


for T_reg = 2:13
    om_r = 2*pi/T_reg;
    om_rounded = interp1(om,om,om_r,'nearest');
    j = find(om==om_rounded);
for ti = 1:nt
       k = (om_r^2)/g;
          
       %%% HEAVE FORCES %%%
       %FROUDE-KRILOFF
       F_fkh(ti,T_reg) = rho*g*A_n*exp(k*z)*(B+2*f)*(2/k)*...
           sin(k*(2*f+L)/2)*sin(om_r*t(ti));
              
       %DIFFRACTION
       F_dh(ti,T_reg) = (Ma_heave(j)/(2*f+L))*(-(om_r)^2)*A_n*exp(k*zm)*...
           (2/k)*sin(k*(2*f+L)/2)*sin(om_r*t(ti));
       
       %%% SWAY FORCES %%%
       %FROUDE-KRILOFF - forces on both edges
       F_fks(ti,T_reg) = rho*g*A_n*B*((1-exp(z*k))/k)*...
           sin(om_r*t(ti)-k*(-L/2)) - ... x = -L/2
           rho*g*A_n*B*((1-exp(z*k))/k)*sin(om_r*t(ti)...
           -k*(L/2)) ; % x = L/2
             
       %DIFFRACTION FORCE
       F_ds(ti,T_reg) = (om_r)^2*A_n*(Ma_sway(j)/d)*((1-exp(z*k))/k)*...
           cos(om_r*t(ti)-k*0) ; %x_mid =0
              
       %%% ROLL MOMENTS %%%
       %FROUDE KRILOFF MOMENT
       F_fkr(ti,T_reg) =  rho*g*A_n*exp(k*z)*(B+2*f)*...
           (cos(om_r*t(ti))*(k*(2*f+L)*cos(k*(2*f+L)/2)-2*sin(k*(2*f+L)/2))/(k^2));
       
       %DIFFRACTION MOMENT
       F_dr(ti,T_reg) = (Ma_heave(j)/(2*f+L))*(-(om_r)^2)*A_n*exp(k*zm)*...
           (cos(om_r*t(ti))*(k*(2*f+L)*cos(k*(2*f+L)/2)-2*sin(k*(2*f+L)/2))/(k^2));
  
end
end


F_heave =F_fkh+F_dh;
F_sway = F_fks+F_ds;
F_roll = F_fkr+F_dr;

% WRITE FORCES TO FILE
% must be run on computer with excel for windows
% xlswrite('regforce.xlsx', F_heave,1) 
% xlswrite('regforce.xlsx', F_sway,2)
% xlswrite('regforce.xlsx', F_roll,3)


% CREATE VARIOUS PLOTS 
% 
% PLOT HEAVE FORCES FOR REGULAR WAVES, T=2-13 S
figure
for i =2:13
subplot(3,4,i-1)
plot(t(1:130),F_heave(1:130,i),'linewidth',2)
set(gca,'FontSize',14)
title(['T = ' num2str(i) 's'])
xlim([0 26])
end
t_r = suptitle('Heave');
set(t_r, 'fontsize',18)

%% PLOT SWAY FORCES FOR REGULAR WAVES, T=2-13 S
figure
for i =2:13
subplot(3,4,i-1)
plot(t(1:130),F_sway(1:130,i),'linewidth',2)
set(gca,'FontSize',14)
title(['T = ' num2str(i) 's'])
xlim([0 26])
end
t_r = suptitle('Sway');
set(t_r, 'fontsize',18)

%% PLOT ROLL MOMENTS FOR REGULAR WAVES, T=2-13 S
figure
for i =2:13
subplot(3,4,i-1)
plot(t(1:130),F_roll(1:130,i),'linewidth',2)
set(gca,'FontSize',14)
title(['T = ' num2str(i) 's'])
xlim([0 26])
end
t_r = suptitle('Roll');
set(t_r, 'fontsize',18)

end